@@ -1,5 +1,9 @@
 use anyhow::Result;
+use aqueue::actor::Actor;
 use aqueue::AQueue;
+use async_trait::async_trait;
+use futures_util::try_join;
+use std::cell::Cell;
 use std::sync::Arc;
 use std::time::Instant;
 use tokio::time::{sleep, Duration};
@@ -17,14 +21,15 @@ async fn test_base() -> Result<()> {
                 |_| async move {
                     println!("a");
                     //delay_for(Duration::from_secs(1)).await;
-                    Ok(1)
+                    1
                 },
                 (),
             )
             .await;
 
         println!("{:?}", x);
-    });
+    })
+    .await?;
 
     let a_queue = queue.clone();
     tokio::spawn(async move {
@@ -33,14 +38,14 @@ async fn test_base() -> Result<()> {
                 .run(
                     |_| async move {
                         println!("b:{}", i);
-                        Ok(())
+                        ()
                     },
                     (),
                 )
-                .await
-                .unwrap();
+                .await;
         }
-    });
+    })
+    .await?;
 
     sleep(Duration::from_secs(2)).await;
 
@@ -52,12 +57,12 @@ async fn test_base() -> Result<()> {
                 |x| async move {
                     unsafe {
                         VALUE += x;
-                        Ok(VALUE)
+                        VALUE
                     }
                 },
                 i,
             )
-            .await?;
+            .await;
     }
 
     println!("{} {}", start.elapsed().as_secs_f32(), v);
@@ -71,23 +76,18 @@ async fn test_base() -> Result<()> {
 async fn test_string() -> Result<()> {
     let queue = Arc::new(AQueue::new());
     let str = 12345.to_string();
-    let len = queue.run(|x| async move { Ok(x.len()) }, str).await?;
+    let len = queue.run(|x| async move { x.len() }, str).await;
     assert_eq!(len, 5);
     struct Foo {
         i: i32,
     }
     let foo = Foo { i: 5 };
-    let len = queue.run(|x| async move { Ok(x.i) }, foo).await?;
+    let len = queue.run(|x| async move { x.i }, foo).await;
     assert_eq!(len, 5);
 
     Ok(())
 }
 
-use aqueue::actor::Actor;
-use async_trait::async_trait;
-use std::cell::Cell;
-use tokio::task::JoinHandle;
-
 #[tokio::test]
 async fn test_struct() -> Result<()> {
     #[async_trait]
@@ -130,10 +130,7 @@ async fn test_struct() -> Result<()> {
     #[async_trait]
     impl IFoo for MakeActorIFoo {
         async fn run(&self, x: i32, y: i32) -> i32 {
-            self.queue
-                .run(|inner| async move { Ok(inner.run(x, y).await) }, self.inner.clone())
-                .await
-                .unwrap()
+            self.queue.run(|inner| async move { inner.run(x, y).await }, self.inner.clone()).await
         }
 
         fn get_count(&self) -> i32 {
@@ -146,13 +143,7 @@ async fn test_struct() -> Result<()> {
     let x = make.run(1, 2).await;
     assert_eq!(x, 3);
 
-    let start = Instant::now();
-    for i in 0..2000000 {
-        make.run(i, i).await;
-    }
-
-    println!("{} {}", start.elapsed().as_secs_f32(), make.inner.get_count());
-
+    let begin = Instant::now();
     let a_make = make.clone();
     let a = tokio::spawn(async move {
         let start = Instant::now();
@@ -173,8 +164,18 @@ async fn test_struct() -> Result<()> {
         println!("b {} {}", start.elapsed().as_secs_f32(), b_make.inner.get_count());
     });
 
-    a.await?;
-    b.await?;
+    let c = tokio::spawn(async move {
+        let start = Instant::now();
+        for i in 0..2000000 {
+            make.run(i, i).await;
+        }
+        println!("c {} {}", start.elapsed().as_secs_f32(), make.inner.get_count());
+    });
+
+    try_join!(a, b, c)?;
+
+    println!("all secs:{}", begin.elapsed().as_secs_f32());
+
     Ok(())
 }
 
@@ -276,45 +277,54 @@ async fn test_actor() -> Result<()> {
 
     #[async_trait]
     pub trait FooRunner {
-        async fn set(&self, x: i32, y: i32) -> Result<i32>;
-        async fn get(&self) -> Result<(i32, i32, i32)>;
-        async fn get_len<'a>(&'a self, b: &'a [u8]) -> Result<usize>;
+        async fn set(&self, x: i32, y: i32) -> i32;
+        async fn get(&self) -> (i32, i32, i32);
+        async fn get_len<'a>(&'a self, b: &'a [u8]) -> usize;
     }
 
     #[async_trait]
     impl FooRunner for Actor<Foo> {
-        async fn set(&self, x: i32, y: i32) -> Result<i32> {
-            self.inner_call(|inner| async move { Ok(inner.get_mut().set(x, y).await) }).await
+        async fn set(&self, x: i32, y: i32) -> i32 {
+            self.inner_call(|inner| async move { inner.get_mut().set(x, y).await }).await
         }
 
-        async fn get(&self) -> Result<(i32, i32, i32)> {
-            self.inner_call(|inner| async move { Ok(inner.get().get()) }).await
+        async fn get(&self) -> (i32, i32, i32) {
+            self.inner_call(|inner| async move { inner.get().get() }).await
         }
 
-        async fn get_len<'a>(&'a self, b: &'a [u8]) -> Result<usize> {
-            unsafe { self.inner_call_ref(|_| async move { Ok(b.len()) }).await }
+        async fn get_len<'a>(&'a self, b: &'a [u8]) -> usize {
+            self.inner_call(|_| async move { b.len() }).await
         }
     }
 
     let a_foo = Arc::new(Actor::new(Foo::default()));
     let b_foo = a_foo.clone();
-    let b: JoinHandle<Result<()>> = tokio::spawn(async move {
+    let b = tokio::spawn(async move {
         for i in 0..100 {
-            let x = b_foo.set(i - 1, i + 1).await?;
-            println!("i:{}", x);
+            let x = b_foo.set(i - 1, i + 1).await;
+            println!("b:{}", x);
+        }
+    });
+
+    let c_foo = a_foo.clone();
+    let c = tokio::spawn(async move {
+        for i in 0..100 {
+            let x = c_foo.set(i - 1, i + 1).await;
+            println!("c:{}", x);
         }
-        Ok(())
     });
 
     for i in 200..300 {
-        let x = a_foo.set(i - 1, i + 1).await?;
-        println!("i:{}", x);
+        let x = a_foo.set(i - 1, i + 1).await;
+        println!("a:{}", x);
     }
-    b.await??;
-    assert_eq!((200, 29700, 30100), a_foo.get().await?);
+
+    try_join!(b, c)?;
+
+    assert_eq!((300, 34550, 35150), a_foo.get().await);
 
     let buff = vec![1, 2, 3, 4, 5];
-    let x = { a_foo.get_len(&buff[..]).await? };
+    let x = { a_foo.get_len(&buff[..]).await };
     assert_eq!(buff.len(), x);
 
     Ok(())
